package org.w3c.rdf.syntax.xml;

import java.util.*;

public class Element {

  public static final String EMPTY_STR = "";
  public static final int EMPTY = 0;
  public static final int CDATA = 1;
  public static final int ELEMENTS = 2;
  public static final int MIXED = CDATA | ELEMENTS;

  public static final Enumeration EMPTY_ENUMERATION = new Enumeration() {

    public boolean hasMoreElements() {
      return false;
    }
    public Object nextElement() {
      throw new NoSuchElementException("ElementEnumerator");
    }
  };

  protected int type = EMPTY;
  protected Element parent;
  /**
   * we consider a single child at a time
   */
  protected Element child;
  protected String name;
  /**
   * If element is CDATA
   */
  protected String value = EMPTY_STR;
  protected Hashtable attrs;

  public Element() {
  }

  public void setName(String name) {
    this.name = name;
  }

  public String getName() {
    return name;
  }

  public int getType() {
    return type;
  }

  public String getValue() {
    return value;
  }

  public void setValue(String value) {
    this.value = value;
    type |= CDATA;
  }

  public Element getParent() {
    return parent;
  }

  public void setParent(Element parent) {
    this.parent = parent;
  }

  public void setChild(Element child) {
    this.child = child;
    type |= ELEMENTS;
  }

  /*
  public Enumeration getProperAttributes() {

    if(attrs == null)
      return EMPTY_ENUMERATION;
    return new ProperEnumeration(attrs);
  }
  */

  public Enumeration getAttributes() {

    if(attrs == null)
      return EMPTY_ENUMERATION;
    else
      return attrs.keys();
  }

  public void setAttribute(String name, String value) {

    if(attrs == null)
      attrs = new Hashtable();
    attrs.put(name, value);
  }

  public String getAttribute(String name) {

    if(attrs == null)
      return null;
    else
      return (String)attrs.get(name);
  }


  /**
   * returns attribute names that are not xmlns...
  class ProperEnumeration {

    Object current = null;

    public ProperEnumeration(Enumeration en) {
      this.en = en;
    }

    public boolean hasMoreElements() {
      return findNext() != null;
    }

    Object findNext() {

      while(current == null && en.hasMoreElements()) {

	String aName = (String)en.nextElement();
	if(!aName.startsWith("xmlns"))
	  current = aName;
      }
      return current;
    }

    public Object nextElement() {

      Object res = findNext();
      current = null;
      return res;
    }
  }
   */

}
